==> kmud-0.5.tar.gz: kmud-0.5/kmud/dialogs/dlgmapoptionscolours.cpp <==
/***************************************************************************
                          dlgmapoptionscolours.cpp
                      -------------------
    description          :
    begin                : Thu Sep 14 2000
    copyright            : (C) 2000 by Stephan Uhlmann
    email                : suhlmann@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include "dlgmapoptionscolours.h"

DlgMapOptionsColours::DlgMapOptionsColours(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	initDialog();
}

DlgMapOptionsColours::~DlgMapOptionsColours()
{
}

void DlgMapOptionsColours::setBackgroundColour(QColor col)
{
	cmdBackground->setColor(col);
}

void DlgMapOptionsColours::setGridColour(QColor col)
{
	cmdGrid->setColor(col);
}

void DlgMapOptionsColours::setDefaultRoomColour(QColor col)
{
	cmdRoomColor->setColor(col);
}

void DlgMapOptionsColours::setDefaultPathColour(QColor col)
{
	cmdPathColor->setColor(col);
}

void DlgMapOptionsColours::setDefaultTextColour(QColor col)
{
	cmdTextColour->setColor(col);
}

void DlgMapOptionsColours::setSelectedColour(QColor col)
{
	cmdSelected->setColor(col);
}

void DlgMapOptionsColours::setLoginColour(QColor col)
{
	cmdLogin->setColor(col);
}

void DlgMapOptionsColours::setLowerRoomColour(QColor col)
{
	cmdLoRoomColor->setColor(col);
}

void DlgMapOptionsColours::setLowerPathColour(QColor col)
{
	cmdLoPathColor->setColor(col);
}

void DlgMapOptionsColours::setHigherRoomColour(QColor col)
{
	cmdHiRoomColor->setColor(col);
}

void DlgMapOptionsColours::setHigherPathColour(QColor col)
{
	cmdHiPathColor->setColor(col);
}


QColor DlgMapOptionsColours::getBackgroundColour(void)
{
	return cmdBackground->color();
}

QColor DlgMapOptionsColours::getGridColour(void)
{
	return cmdGrid->color();
}

QColor DlgMapOptionsColours::getDefaultRoomColour(void)
{
	return cmdRoomColor->color();
}

QColor DlgMapOptionsColours::getDefaultPathColour(void)
{
	return cmdPathColor->color();
}

QColor DlgMapOptionsColours::getLowerRoomColour(void)
{
	return cmdLoRoomColor->color();
}

QColor DlgMapOptionsColours::getLowerPathColour(void)
{
	return cmdLoPathColor->color();
}

QColor DlgMapOptionsColours::getHigherRoomColour(void)
{
	return cmdHiRoomColor->color();
}

QColor DlgMapOptionsColours::getHigherPathColour(void)
{
	return cmdHiPathColor->color();
}

QColor DlgMapOptionsColours::getSelectedColour(void)
{
	return cmdSelected->color();
}

QColor DlgMapOptionsColours::getLoginColour(void)
{
	return cmdLogin->color();
}

QColor DlgMapOptionsColours::getDefaultTextColour(void)
{
	return cmdTextColour->color();
}

==> kmud-1.0.tar.gz: kmud-1.0/kmud/dialogs/dlgmapoptionscolours.cpp <==
/***************************************************************************
                          dlgmapoptionscolours.cpp
                      -------------------
    description          :
    begin                : Thu Sep 14 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include "dlgmapoptionscolours.h"

DlgMapOptionsColours::DlgMapOptionsColours(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	initDialog();
}

DlgMapOptionsColours::~DlgMapOptionsColours()
{
}

void DlgMapOptionsColours::setBackgroundColour(QColor col)
{
	cmdBackground->setColor(col);
}

void DlgMapOptionsColours::setGridColour(QColor col)
{
	cmdGrid->setColor(col);
}

void DlgMapOptionsColours::setDefaultRoomColour(QColor col)
{
	cmdRoomColor->setColor(col);
}

void DlgMapOptionsColours::setDefaultPathColour(QColor col)
{
	cmdPathColor->setColor(col);
}

void DlgMapOptionsColours::setDefaultTextColour(QColor col)
{
	cmdTextColour->setColor(col);
}

void DlgMapOptionsColours::setCurrentColour(QColor col)
{
	cmdCurrent->setColor(col);
}

void DlgMapOptionsColours::setEditColour(QColor col)
{
	cmdEdit->setColor(col);
}

void DlgMapOptionsColours::setSelectedColour(QColor col)
{
	cmdSelected->setColor(col);
}

void DlgMapOptionsColours::setSpecialColour(QColor col)
{
	cmdSpecial->setColor(col);
}

void DlgMapOptionsColours::setLoginColour(QColor col)
{
	cmdLogin->setColor(col);
}

void DlgMapOptionsColours::setLowerRoomColour(QColor col)
{
	cmdLoRoomColor->setColor(col);
}

void DlgMapOptionsColours::setLowerPathColour(QColor col)
{
	cmdLoPathColor->setColor(col);
}

void DlgMapOptionsColours::setHigherRoomColour(QColor col)
{
	cmdHiRoomColor->setColor(col);
}

void DlgMapOptionsColours::setHigherPathColour(QColor col)
{
	cmdHiPathColor->setColor(col);
}


QColor DlgMapOptionsColours::getBackgroundColour(void)
{
	return cmdBackground->color();
}

QColor DlgMapOptionsColours::getGridColour(void)
{
	return cmdGrid->color();
}

QColor DlgMapOptionsColours::getDefaultRoomColour(void)
{
	return cmdRoomColor->color();
}

QColor DlgMapOptionsColours::getDefaultPathColour(void)
{
	return cmdPathColor->color();
}

QColor DlgMapOptionsColours::getLowerRoomColour(void)
{
	return cmdLoRoomColor->color();
}

QColor DlgMapOptionsColours::getLowerPathColour(void)
{
	return cmdLoPathColor->color();
}

QColor DlgMapOptionsColours::getHigherRoomColour(void)
{
	return cmdHiRoomColor->color();
}

QColor DlgMapOptionsColours::getHigherPathColour(void)
{
	return cmdHiPathColor->color();
}

QColor DlgMapOptionsColours::getSelectedColour(void)
{
	return cmdSelected->color();
}

QColor DlgMapOptionsColours::getSpecialColour(void)
{
	return cmdSpecial->color();
}

QColor DlgMapOptionsColours::getLoginColour(void)
{
	return cmdLogin->color();
}

QColor DlgMapOptionsColours::getDefaultTextColour(void)
{
	return cmdTextColour->color();
}

QColor DlgMapOptionsColours::getCurrentColour(void)
{
	return cmdCurrent->color();
}

QColor DlgMapOptionsColours::getEditColour(void)
{
	return cmdEdit->color();
}
